# Make sure that package build dependencies are installed
#
# Copyright (C) 2012, 2014 Patrick McDermott
#
# This file is part of opkbuild.
#
# opkbuild is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# opkbuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with opkbuild.  If not, see <http://www.gnu.org/licenses/>.

set -eu

check_dep()
{
	local dep="${1}"
	local dep_pkg=
	local dep_rel=
	local dep_ver=
	local status=
	local pkg_ver=

	# Leave stdout for caller to collect.
	ob_parse_dep -P dep_pkg -r dep_rel -v dep_ver -- "${dep}"
	status="$("${OPKG}" status "${dep_pkg}")"

	if ! printf '%s\n' "${status}" | grep '^Status: .* .* installed$' \
			>/dev/null 2>&1; then
		return 1
	fi
	if [ "x${dep_rel}" != 'x' ]; then
		pkg_ver="$(printf '%s\n' "${status}" | \
			sed -n 's/^Version: //p')"
		# opkg returns 1 on a true comparison, 0 on a false comparison.
		if "${OPKG}" compare-versions \
				"${pkg_ver}" "${dep_rel}" "${dep_ver}"; then
			return 1
		fi
	fi

	return 0
}

check_build_deps()
{
	local deps=
	local missing=
	local dep=

	ob_info "$(ob_get_msg 'checking_build_deps')"

	deps="$(ob_get_source_parameter 'Build-Depends')"
	deps="$(ob_reduce_deps -a "${OPK_HOST_ARCH}" \
		-p "${OPK_HOST_PLAT}" -- "${deps}")"
	deps="$(ob_substvars "${deps}")"

	missing=''
	IFS=','
	for dep in ${deps}; do
		unset IFS
		if ! dep="$(check_dep "${dep}")"; then
			missing="${missing}, ${dep}"
		fi
	done
	unset IFS

	missing="${missing#, }"
	if [ "x${missing}" != 'x' ]; then
		ob_error "$(ob_get_msg 'missing_build_deps')" "${missing}"
		return 1
	fi

	return 0
}

main()
{
	if ! ob_set_text_domain 'opkbuild'; then
		printf '%s: Error: Failed to load locale messages\n' \
			"${0##*/}" >&2
		return 1
	fi

	ob_init_package '..' || return 1
	ob_set_package_substvars ''

	check_build_deps || return ${?}

	return 0
}
